Learn R Programming

lrgs (version 0.5.4)

lrgs-package: Linear Regression by Gibbs Sampling

Description

Implements a Gibbs sampler to do linear regression with multiple covariates, multiple responses, Gaussian measurement errors on covariates and responses, Gaussian intrinsic scatter, and a covariate prior distribution which is given by either a Gaussian mixture of specified size or a Dirichlet process with a Gaussian base distribution.

Arguments

Details

Package: lrgs
Type: Package
Version: 0.5.4
Date: 2018-05-17
License: MIT
LazyLoad: yes

See help for Gibbs.regression